## 上市公司全量公告

接口：anns_d

描述：获取全量公告数据，提供pdf下载URL

限量：单次最大2000条数，可以跟进日期循环获取全量

权限：本接口为单独权限，请参考权限说明

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 股票代码 |
| ann_date | str | N | 公告日期（yyyymmdd格式，下同） |
| start_date | str | N | 公告开始日期 |
| end_date | str | N | 公告结束日期 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ann_date | str | Y | 公告日期 |
| ts_code | str | Y | 股票代码 |
| name | str | Y | 股票名称 |
| title | str | Y | 标题 |
| url | str | Y | URL，原文下载链接 |
| rec_time | datetime | N | 发布时间 |

接口调用

```python
pro = ts.pro_api()

df = pro.anns_d(ann_date='20230621')
```

数据样例

```python
ann_date    ts_code  name                                              title
0     20230621  600590.SH  泰豪科技                                   第八届董事会第十五次会议决议公告
```